==> haskell-persistent-test-2.0.3.0-16-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-test
version: 2.0.3.0
id: persistent-test-2.0.3.0-769WWmN9jCE2G5F9AAgVhF
key: persistent-test-2.0.3.0-769WWmN9jCE2G5F9AAgVhF
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.
category: Database, Yesod
abi: 8eefe043e80cd9acffd12c9a6a5cdc93
exposed: True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest HtmlTest Init
    LargeNumberTest MaxLenTest MigrationColumnLengthTest
    MigrationIdempotencyTest MigrationOnlyTest MigrationTest
    MpsNoPrefixTest PersistTestPetCollarType PersistTestPetType
    PersistUniqueTest PersistentTest PersistentTestModels PrimaryTest
    RawSqlTest ReadWriteTest Recursive RenameTest SumTypeTest
    TransactionLevelTest TreeTest UniqueTest UpsertTest
import-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-test-2.0.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-test-2.0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/persistent-test-2.0.3.0
hs-libraries: HSpersistent-test-2.0.3.0-769WWmN9jCE2G5F9AAgVhF
depends:
    HUnit-1.6.0.0-JbqplLUCHWj8gC9WuQWK9
    QuickCheck-2.13.2-C3chvSwT3GSBClgQ9bo1MW
    aeson-1.4.4.0-B759jesA16BBzbLoqI31GW base-4.12.0.0
    blaze-html-0.9.1.1-4JkTtLEB4Yx9lkhlQlW7SA bytestring-0.10.8.2
    conduit-1.3.1.1-CfM5hRP1Ia6GpnibXcmH9G containers-0.6.0.1
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt
    hspec-2.7.1-HJCUFd7ibyAFZeyKsOubud
    hspec-expectations-0.8.2-KPRvFAznc6K3R1q20h88eD
    monad-control-1.0.2.3-8Pxhw440UA44O8KsVrptNh
    monad-logger-0.3.30-2kmzjTpC8MSG6LltA7aDUf
    path-pieces-0.2.1-7jseLTOU0PkHMQiwNvt0jG
    persistent-2.10.1-7pXWa2dlvJy4zQ0L3Ek9xr
    persistent-template-2.7.2-4whWR0bvC4g9aYhEXioa9u
    quickcheck-instances-0.3.22-KYU7WtEhMxd7UzhGsfMGck
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0 text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2
    transformers-base-0.4.5.2-Kv4g21XBkulAq9rkP7VoYL
    unliftio-0.2.12-3yNjSppSs7R15wXSO1FOyS
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
haddock-interfaces: /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock
haddock-html: /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-persistent-test-2.0.3.0-24-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-persistent-test.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: persistent-test
version: 2.0.3.0
id: persistent-test-2.0.3.0-GktdM1SAZi6IkPuA6EFLqU
key: persistent-test-2.0.3.0-GktdM1SAZi6IkPuA6EFLqU
license: MIT
maintainer: Michael Snoyman <michael@snoyman.com>
author: Michael Snoyman <michael@snoyman.com>
stability: Stable
homepage: http://www.yesodweb.com/book/persistent
synopsis: Tests for Persistent
description:
    Tests for Persistent. This is only for use in developing libraries that should conform to the persistent interface, not for users of the persistent suite of database libraries.
category: Database, Yesod
abi: f0e7abf5b84448fec4bde142beb23e9a
exposed: True
exposed-modules:
    CompositeTest CustomPersistField CustomPersistFieldTest
    CustomPrimaryKeyReferenceTest DataTypeTest EmbedOrderTest EmbedTest
    EmptyEntityTest EntityEmbedTest EquivalentTypeTest HtmlTest Init
    LargeNumberTest MaxLenTest MigrationColumnLengthTest
    MigrationIdempotencyTest MigrationOnlyTest MigrationTest
    MpsNoPrefixTest PersistTestPetCollarType PersistTestPetType
    PersistUniqueTest PersistentTest PersistentTestModels PrimaryTest
    RawSqlTest ReadWriteTest Recursive RenameTest SumTypeTest
    TransactionLevelTest TreeTest UniqueTest UpsertTest
import-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-test-2.0.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/persistent-test-2.0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/persistent-test-2.0.3.0
hs-libraries: HSpersistent-test-2.0.3.0-GktdM1SAZi6IkPuA6EFLqU
depends:
    HUnit-1.6.0.0-JbqplLUCHWj8gC9WuQWK9
    QuickCheck-2.13.2-C3chvSwT3GSBClgQ9bo1MW
    aeson-1.4.4.0-B759jesA16BBzbLoqI31GW base-4.12.0.0
    blaze-html-0.9.1.1-4JkTtLEB4Yx9lkhlQlW7SA bytestring-0.10.8.2
    conduit-1.3.1.1-4WoHy8vBnBFBnZww6g0450 containers-0.6.0.1
    exceptions-0.10.3-L2x6PdAsyEqAgSjmGnIOPt
    hspec-2.7.1-HJCUFd7ibyAFZeyKsOubud
    hspec-expectations-0.8.2-KPRvFAznc6K3R1q20h88eD
    monad-control-1.0.2.3-8Pxhw440UA44O8KsVrptNh
    monad-logger-0.3.30-BBOvFsZkZCA5ie1Efxjd0q
    path-pieces-0.2.1-7jseLTOU0PkHMQiwNvt0jG
    persistent-2.10.1-9hMHVKxwS15GE6CcgnrRnW
    persistent-template-2.7.2-HvMENDlNigJ1LWNgpBmpKE
    quickcheck-instances-0.3.22-KYU7WtEhMxd7UzhGsfMGck
    random-1.1-3ypV4EIycgb35PKjTYYr5q
    resourcet-1.2.2-JLxEmnu4VEmKsSbOPjgbf0 text-1.2.3.1 time-1.8.0.2
    transformers-0.5.6.2
    transformers-base-0.4.5.2-Kv4g21XBkulAq9rkP7VoYL
    unliftio-0.2.12-3yNjSppSs7R15wXSO1FOyS
    unliftio-core-0.1.2.0-DmlZdkLzX278vkyONsp8WQ
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
haddock-interfaces: /usr/share/doc/haskell-persistent-test/html/persistent-test.haddock
haddock-html: /usr/share/doc/haskell-persistent-test/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
